==> kadu_1.3.orig.tar.bz2: kadu-1.3/plugins/sql_history/translations/sql_history_zh_CN.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_CN" version="2.0">
<context>
    <name>HistorySqlStorage</name>
    <message>
        <source>Preparing history database...</source>
        <translation>正在准备历史数据库...</translation>
    </message>
    <message>
        <source>History</source>
        <translation>历史</translation>
    </message>
    <message>
        <source>Opening database failed. Error message:
%1</source>
        <translation>打开数据库失败. 错误消息
%1</translation>
    </message>
</context>
<context>
    <name>SqlInitializer</name>
    <message>
        <source>Copying history file to new location: %1 ...</source>
        <translation>正在复制历史文件到新位置: %1...</translation>
    </message>
    <message>
        <source>Unable to copy history file to new location. Check if disk is full.</source>
        <translation>无法将历史文件复制到新位置. 请检查是否有足够的剩余磁盘空间.</translation>
    </message>
    <message>
        <source>Unable to open database: %1</source>
        <translation>不能打开数据库: %1</translation>
    </message>
    <message>
        <source>History file is corrupted, performing recovery...</source>
        <translation>历史文件已损坏. 正在恢复...</translation>
    </message>
    <message>
        <source>Recovery completed.</source>
        <translation>恢复完成.</translation>
    </message>
    <message>
        <source>Recovery failed: %s</source>
        <translation>恢复失败: %s</translation>
    </message>
    <message>
        <source>History file is outdated, performing import...</source>
        <translation>历史文件已过时. 正在导入...</translation>
    </message>
    <message>
        <source>Import completed.</source>
        <translation>导入完成.</translation>
    </message>
    <message>
        <source>Copying completed.</source>
        <translation>复制完成.</translation>
    </message>
</context>
<context>
    <name>SqlRestore</name>
    <message>
        <source>No error.</source>
        <translation>无错误.</translation>
    </message>
    <message>
        <source>sqlite3 executable not found.</source>
        <translation>sqlite3 主程序未找到.</translation>
    </message>
    <message>
        <source>Invalid invocation of recovery script.</source>
        <translation>恢复脚本出现无效调用.</translation>
    </message>
    <message>
        <source>Unable to read corrupted database.</source>
        <translation>无法读取损坏的数据库.</translation>
    </message>
    <message>
        <source>Unable to create backup file. Disc may be full.</source>
        <translation>无法创建备份文件. 磁盘空间可能已满.</translation>
    </message>
    <message>
        <source>Recovery script not found or not executable.</source>
        <translation>恢复脚本未找到或未执行.</translation>
    </message>
    <message>
        <source>Unknown error during database recovery.</source>
        <translation>在数据库恢复期间发生了未知错误.</translation>
    </message>
</context>
</TS>

==> kadu_3.0~rc1.orig.tar.bz2: kadu-3.0-rc1/plugins/sql_history/translations/sql_history_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>HistorySqlStorage</name>
    <message>
        <source>Preparing history database...</source>
        <translation>正在准备历史数据库...</translation>
    </message>
    <message>
        <source>History</source>
        <translation>历史</translation>
    </message>
    <message>
        <source>Opening database failed. Error message:
%1</source>
        <translation>打开数据库失败. 错误消息
%1</translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>It seems your Qt library does not provide support for selected database. Please install Qt with %1 plugin.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SqlInitializer</name>
    <message>
        <source>Copying history file to new location: %1 ...</source>
        <translation>正在复制历史文件到新位置: %1...</translation>
    </message>
    <message>
        <source>Unable to copy history file to new location. Check if disk is full.</source>
        <translation>无法将历史文件复制到新位置. 请检查是否有足够的剩余磁盘空间.</translation>
    </message>
    <message>
        <source>Unable to open database: %1</source>
        <translation>不能打开数据库: %1</translation>
    </message>
    <message>
        <source>History file is corrupted, performing recovery...</source>
        <translation>历史文件已损坏. 正在恢复...</translation>
    </message>
    <message>
        <source>Recovery completed.</source>
        <translation>恢复完成.</translation>
    </message>
    <message>
        <source>Recovery failed: %s</source>
        <translation>恢复失败: %s</translation>
    </message>
    <message>
        <source>History file is outdated, performing import...</source>
        <translation>历史文件已过时. 正在导入...</translation>
    </message>
    <message>
        <source>Import completed.</source>
        <translation>导入完成.</translation>
    </message>
    <message>
        <source>Copying completed.</source>
        <translation>复制完成.</translation>
    </message>
</context>
<context>
    <name>SqlRestore</name>
    <message>
        <source>No error.</source>
        <translation>无错误.</translation>
    </message>
    <message>
        <source>sqlite3 executable not found.</source>
        <translation>sqlite3 主程序未找到.</translation>
    </message>
    <message>
        <source>Invalid invocation of recovery script.</source>
        <translation>恢复脚本出现无效调用.</translation>
    </message>
    <message>
        <source>Unable to read corrupted database.</source>
        <translation>无法读取损坏的数据库.</translation>
    </message>
    <message>
        <source>Unable to create backup file. Disc may be full.</source>
        <translation>无法创建备份文件. 磁盘空间可能已满.</translation>
    </message>
    <message>
        <source>Recovery script not found or not executable.</source>
        <translation>恢复脚本未找到或未执行.</translation>
    </message>
    <message>
        <source>Unknown error during database recovery.</source>
        <translation>在数据库恢复期间发生了未知错误.</translation>
    </message>
</context>
</TS>
